==> doorstep_services-1.0.2.tar.gz: doorstep_services/README.md <==
Doorstep Services

CONTENTS
---------------------

 * Introduction
 * Installation
 * Configuration
 * Additional Requirements
 * Maintainers


INTRODUCTION
------------
The Doorstep Services module enables users to register for various service requests and receive notifications about their requests via email. Users can view, edit, and cancel their own requests if needed. Administrators have the ability to update the status of service requests and generate PDF bills, which are sent via email to both the customer and a copy to the admin's email account. Additionally, administrators can filter service requests based on their status type.

 * For a full description of the module, visit the project page:
   https://www.drupal.org/project/doorstep_services

 * To submit bug reports and feature suggestions, or to track changes:
   https://www.drupal.org/project/issues/doorstep_services




INSTALLATION
------------

 * Install as you would normally install a contributed Drupal module. Visit:
   https://www.drupal.org/node/1897420 for further information.


CONFIGURATION
-------------

 * To register service request navigate to /doorstep-services/register
 * To view all requests navigate to /admin/service-requests
 * To view customers own requests navigate to /user-requests


Additional Requirements
-----------
* Requires SMTP module https://www.drupal.org/project/smtp
* Requires tecnickcom/tcpdf library. To install visit https://packagist.org/packages/tecnickcom/tcpdf

MAINTAINERS
-----------

Current maintainer:
 * Chaitanya R Dessai

==> doorstep_services-1.0.5.tar.gz: doorstep_services/README.md <==
Doorstep Services

CONTENTS
---------------------

 * Introduction
 * Installation
 * Configuration
 * Additional Requirements
 * Maintainers


INTRODUCTION
------------
The Doorstep Services module enables users to register for various service requests and receive notifications about their requests via email. Users can view, edit, and cancel their own requests if needed. Administrators have the ability to update the status of service requests and generate PDF bills, which are sent via email to both the customer and a copy to the admin's email account. Additionally, administrators can filter service requests based on their status type.

 * For a full description of the module, visit the project page:
   https://www.drupal.org/project/doorstep_services

 * To submit bug reports and feature suggestions, or to track changes:
   https://www.drupal.org/project/issues/doorstep_services




INSTALLATION
------------

 * Install as you would normally install a contributed Drupal module. Visit:
   https://www.drupal.org/node/1897420 for further information.


CONFIGURATION
-------------

 * To register service request navigate to /doorstep-services/register
 * To view all requests navigate to /admin/service-requests
 * To view customers own requests navigate to /user-requests


Additional Requirements
-----------
* Requires SMTP module https://www.drupal.org/project/smtp
* Requires tecnickcom/tcpdf library. https://packagist.org/packages/tecnickcom/tcpdf
* Requires chillerlan/php-qrcode. https://github.com/chillerlan/php-qrcode

MAINTAINERS
-----------

Current maintainer:
 * Chaitanya R Dessai
